import os
import telegram
import requests
from .config import Config

class Tele:

    def get_chat_ids(self):
        url = f"https://api.telegram.org/bot{Config.get_bot_token()}/getUpdates"
        res = requests.get(url)
        res.raise_for_status()
        chats_by_name = {}
        for update in res.json()['result']:
            _chat = update['message']['chat']
            _from = update['message']['from']['username']
            msg_keys = set(update['message'].keys())
            for _key in ['chat', 'date', 'message_id', 'from']:
                if _key in msg_keys:
                    msg_keys.remove(_key)
            chats_by_name[_chat['title']] = chats_by_name.get(_chat['title'],
                                                              _chat['id'])

        return chats_by_name

    def get_chat_id_by_name(self, chat_name):
        return self.get_chat_ids().get(chat_name,
                                       "No such chat name in last updates")
    @staticmethod
    def send_msg(msg, chname):
        _bot = telegram.Bot(token=Config.get_bot_token())
        _bot.send_message(chat_id=Config.get_chat_id(chname),
                         text=msg)

    @staticmethod
    def send_img(photo_stream, chname):
        if photo_stream is None:
            Tele.send_msg('No photo recieved to send', chname)
        else:
            _bot = telegram.Bot(token=Config.get_bot_token())
            _bot.send_photo(chat_id=Config.get_chat_id(chname),
                            photo=photo_stream)
            stat_file_path = Config.get_mashov_stat_file_path()
            if os.path.isfile(stat_file_path):
                os.remove(stat_file_path)



import os
import toml

class Config:
    _CONFIG_PATH = os.path.expanduser("~/.scrap_config.toml")

    @classmethod
    def load(cls, grp=None):
        with open(cls._CONFIG_PATH, 'r') as fh:
            parsed_toml = toml.loads(fh.read())
        if grp:
            return parsed_toml['commands'][grp]
        return parsed_toml

    @classmethod
    def get_chat_id(cls, chname=None):
        if chname:
            with open(cls._CONFIG_PATH, 'r') as fh:
                return toml.loads(fh.read())['telegram']['chats']['id'].get(chname)

    @classmethod
    def get_bot_token(cls):
        with open(cls._CONFIG_PATH, 'r') as fh:
            return toml.loads(fh.read())['commands']['telegram']['bot_token']

    @classmethod
    def get_mashov_stat_file_path(cls):
        with open(cls._CONFIG_PATH, 'r') as fh:
            return toml.loads(fh.read())['commands']['mashov']['stat_img_file']



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['infrascrap']

package_data = \
{'': ['*']}

install_requires = \
['bitwarden-keyring>=0.3.0,<0.4.0',
 'keyring>=21.2.1,<22.0.0',
 'python-telegram-bot>=12.8,<13.0',
 'pyvirtualdisplay>=1.3.2,<2.0.0',
 'requests>=2.24.0,<3.0.0',
 'selenium>=3.141.0,<4.0.0',
 'toml>=0.10.1,<0.11.0']

setup_kwargs = {
    'name': 'infrascrap',
    'version': '0.1.4',
    'description': 'Scraping infrastructure',
    'long_description': None,
    'author': 'Sivan Becker',
    'author_email': 'sivanbecker@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



import re
import os
import keyring
from selenium import webdriver
from selenium.webdriver.chrome.options import Options
from contextlib import contextmanager
from .exceptions import MissingBitWardenToken, BrowserException
from pyvirtualdisplay import Display

class BaseScrap:

    def __init__(self, cfg):
        if not all([e in cfg for e in ('username', 'bitwarden_service')]):
            raise KeyError('Missing one or more of the keys: username,bitwarden_service in config')

        self.username = cfg['username']
        self.bw_service = cfg['bitwarden_service']
        self.set_attrs_by_cfg_params(cfg)

    @property
    def pw(self):
        return self._bw_password

    def _bw_password(self):
        if os.environ.get('BW_SESSION') is None:
            raise MissingBitWardenToken('You did not login to bitwarden - Expecting BW_SESSION env var..')
        return keyring.get_password(self.bw_service,
                                    self.username)

    def set_attrs_by_cfg_params(self, cfg):
        ''' config may contain keys like _param_<param name>
        and this function should set self.<param_name> with the value from config
        '''
        for k, val in cfg.items():
            mtch = re.search("_param_(.*)", k)
            if mtch:
                self.__setattr__(mtch.group(1), val)

@contextmanager
def BrowserGCM(headless=True):
    ''' Browser context manager implemented with generators'''
    def init_browser(_headless):
        chrome_options = Options()
        if _headless:
            chrome_options.add_argument("--headless")
            chrome_options.add_argument("--no-sandbox")

        try:
            display = Display(visible=0, size=(800, 600))
            display.start()
        except Exception as e:
            print(f'Failed loading virtual display {e}')
            raise BrowserException(e)

        return webdriver.Chrome(options=chrome_options)
    try:
        _browser = init_browser(headless)
        yield _browser
    except Exception as exc:
        print(f'Failed init browser ?? {exc}')
        raise BrowserException(exc)
    finally:
        if _browser:
            _browser.quit()
